@@ -1,6 +1,8 @@
 /*
  * playlist.c -- Functions to control playlist objects
- * Copyright (C) 2007 Alberto Garcia <agarcia@igalia.com>
+ *
+ * Copyright (C) 2007-2009 Igalia, S.L.
+ * Authors: Alberto Garcia <agarcia@igalia.com>
  *
  * This file is part of Vagalume and is published under the GNU GPLv3.
  * See the README file for more details.
@@ -8,27 +10,13 @@
 
 #include "playlist.h"
 
-/**
- * Creates a new LastfmTrack object
- * @return The new track
- */
-LastfmTrack *
-lastfm_track_new(void)
-{
-        LastfmTrack *track = g_slice_new0(LastfmTrack);
-        track->refcount = 1;
-        track->mutex = g_mutex_new();
-        return track;
-}
-
 /**
  * Destroy a LastfmTrack object freeing all its allocated memory
  * @param track Track to be destroyed, or NULL
  */
 static void
-lastfm_track_destroy(LastfmTrack *track)
+lastfm_track_destroy                    (LastfmTrack *track)
 {
-        if (track == NULL) return;
         g_mutex_free(track->mutex);
         g_free ((gpointer) track->stream_url);
         g_free ((gpointer) track->title);
@@ -42,40 +30,22 @@ lastfm_track_destroy(LastfmTrack *track)
         g_free ((gpointer) track->image_data);
         g_free ((gpointer) track->trackauth);
         g_free ((gpointer) track->free_track_url);
-        g_slice_free(LastfmTrack, track);
 }
 
 /**
- * Increments the reference counter of a LastfmTrack object
- * @param track The track
- * @return The same track
+ * Creates a new LastfmTrack object
+ * @return The new track
  */
 LastfmTrack *
-lastfm_track_ref(LastfmTrack *track)
+lastfm_track_new                        (void)
 {
-        g_return_val_if_fail(track != NULL, NULL);
-        g_mutex_lock(track->mutex);
-        track->refcount++;
-        g_mutex_unlock(track->mutex);
+        LastfmTrack *track;
+        track = vgl_object_new (LastfmTrack,
+                                (GDestroyNotify) lastfm_track_destroy);
+        track->mutex = g_mutex_new();
         return track;
 }
 
-/**
- * Decrements the reference counter of a LastfmTrack object. If it
- * reaches 0, then the track is destroyed
- * @param track The track
- */
-void
-lastfm_track_unref(LastfmTrack *track)
-{
-        g_return_if_fail(track != NULL);
-        gboolean destroy;
-        g_mutex_lock(track->mutex);
-        destroy = (--(track->refcount) == 0);
-        g_mutex_unlock(track->mutex);
-        if (destroy) lastfm_track_destroy(track);
-}
-
 /**
  * Set the cover image of a track object, erasing the previous one (if
  * any). After this, the new image data will be owned by this object
@@ -85,7 +55,9 @@ lastfm_track_unref(LastfmTrack *track)
  * @param size Size of the data buffer
  */
 void
-lastfm_track_set_cover_image(LastfmTrack *track, char *data, size_t size)
+lastfm_track_set_cover_image            (LastfmTrack *track,
+                                         char        *data,
+                                         size_t       size)
 {
         g_return_if_fail(track != NULL);
         g_mutex_lock(track->mutex);
@@ -102,7 +74,7 @@ lastfm_track_set_cover_image(LastfmTrack *track, char *data, size_t size)
  * @return The number of tracks in the playlist
  */
 guint
-lastfm_pls_size(LastfmPls *pls)
+lastfm_pls_size                         (LastfmPls *pls)
 {
         g_return_val_if_fail(pls != NULL, 0);
         return g_queue_get_length(pls->tracks);
@@ -113,10 +85,10 @@ lastfm_pls_size(LastfmPls *pls)
  * the track from the playlist (as it can only be played once).
  * @param pls The playlist
  * @return The next track (or NULL if the list is empty). It should be
- * unref'ed with lastfm_track_unref() when no longer used.
+ * unref'ed with vgl_object_unref() when no longer used.
  */
 LastfmTrack *
-lastfm_pls_get_track(LastfmPls *pls)
+lastfm_pls_get_track                    (LastfmPls *pls)
 {
         g_return_val_if_fail(pls != NULL, NULL);
         LastfmTrack *track = NULL;
@@ -132,7 +104,8 @@ lastfm_pls_get_track(LastfmPls *pls)
  * @param track The track to be appended
  */
 void
-lastfm_pls_add_track(LastfmPls *pls, LastfmTrack *track)
+lastfm_pls_add_track                    (LastfmPls   *pls,
+                                         LastfmTrack *track)
 {
         g_return_if_fail(pls != NULL && track != NULL);
         g_queue_push_tail(pls->tracks, track);
@@ -144,7 +117,7 @@ lastfm_pls_add_track(LastfmPls *pls, LastfmTrack *track)
  * lastfm_pls_destroy() when no longer used
  */
 LastfmPls *
-lastfm_pls_new(void)
+lastfm_pls_new                          (void)
 {
         LastfmPls *pls = g_slice_new0(LastfmPls);
         pls->tracks = g_queue_new();
@@ -156,12 +129,12 @@ lastfm_pls_new(void)
  * @param pls The playlist to be cleared
  */
 void
-lastfm_pls_clear(LastfmPls *pls)
+lastfm_pls_clear                        (LastfmPls *pls)
 {
         g_return_if_fail (pls != NULL);
         LastfmTrack *track;
         while ((track = lastfm_pls_get_track(pls)) != NULL) {
-                lastfm_track_unref(track);
+                vgl_object_unref (track);
         }
 }
 
@@ -170,7 +143,7 @@ lastfm_pls_clear(LastfmPls *pls)
  * @param pls The playlist to be destroyed, or NULL.
  */
 void
-lastfm_pls_destroy(LastfmPls *pls)
+lastfm_pls_destroy                      (LastfmPls *pls)
 {
         if (pls == NULL) return;
         lastfm_pls_clear(pls);
@@ -186,7 +159,8 @@ lastfm_pls_destroy(LastfmPls *pls)
  * @param pls2 The second playlist (empty after this operation)
  */
 void
-lastfm_pls_merge(LastfmPls *pls1, LastfmPls *pls2)
+lastfm_pls_merge                        (LastfmPls *pls1,
+                                         LastfmPls *pls2)
 {
         g_return_if_fail(pls1 != NULL && pls2 != NULL);
         LastfmTrack *track;
