@@ -55,7 +55,7 @@ static const char *artists[] = {
 };
 
 static const char appdescr[] = N_("Client for Last.fm and compatible services");
-static const char copyright[] = "(c) 2007-2009 Igalia, S.L.";
+static const char copyright[] = "(c) 2007-2010 Igalia, S.L.";
 static const char website[] = "http://vagalume.igalia.com/";
 static const char license[] =
 "Vagalume is free software: you can redistribute\n"
@@ -75,7 +75,8 @@ static const char license[] =
 static const char translators_tpl[] =
 "%s (de)\n* Stephan Reichholf <stephan@reichholf.net>\n"
          "* Oskar Welzl <mail@welzl.info>\n\n"
-"%s (es)\n* Oscar A. Mata T. <omata_mac@yahoo.com>\n\n"
+"%s (es)\n* Oscar A. Mata T. <omata_mac@yahoo.com>\n"
+         "* Ricardo Mones <mones@debian.org>\n\n"
 "%s (fi)\n* Janne Mäkinen <janne.makinen@surffi.fi>\n"
          "* Mika Tapojärvi <mika.tapojarvi@sse.fi>\n"
          "* Tommi Franttila <tommif@gmail.com>\n\n"
@@ -87,7 +88,9 @@ static const char translators_tpl[] =
 "%s (lv)\n* Pēteris Caune <cuu508@gmail.com>\n\n"
 "%s (pl)\n* Dawid Pakuła (ZuLuS) <zulus@w3des.net>\n\n"
 "%s (pt)\n* Marcos Garcia <marcosgg@gmail.com>\n\n"
-"%s (pt_BR)\n* Rodrigo Flores <rodrigomarquesflores@gmail.com>";
+"%s (pt_BR)\n* Rodrigo Flores <rodrigomarquesflores@gmail.com>\n\n"
+"%s (ru)\n* Sergei Ivanov <isn@vu.spb.ru>\n"
+         "* Vitaly Petrov <vit.petrov@vu.spb.ru>";
 
 /* Don't use gtk_button_new() in Nokia 770 or icons won't appear */
 GtkWidget *
@@ -170,7 +173,8 @@ ui_about_dialog                         (GtkWindow *parent)
                                              _("French"),
                                              _("Galician"), _("Italian"),
                                              _("Latvian"), _("Polish"),
-                                             _("Portuguese"), _("Portuguese"));
+                                             _("Portuguese"), _("Portuguese"),
+                                             _("Russian"));
 #ifdef HAVE_GIO
         gtk_about_dialog_set_url_hook (about_dialog_uri_hook, "", NULL);
         gtk_about_dialog_set_email_hook (about_dialog_uri_hook, "mailto:",
