@@ -1,6 +1,9 @@
 /*
  * vgl-tray-icon.h -- Freedesktop tray icon
- * Copyright (C) 2008 Mario Sanchez Prada <msanchez@igalia.com>
+ *
+ * Copyright (C) 2007-2008 Igalia, S.L.
+ * Authors: Mario Sanchez Prada <msanchez@igalia.com>
+ *          Alberto Garcia <agarcia@igalia.com>
  *
  * This file is part of Vagalume and is published under the GNU GPLv3.
  * See the README file for more details.
@@ -11,6 +14,7 @@
 #include <gtk/gtk.h>
 
 #include "playlist.h"
+#include "controller.h"
 
 G_BEGIN_DECLS
 
@@ -23,10 +27,12 @@ G_BEGIN_DECLS
 
 typedef struct _VglTrayIcon VglTrayIcon;
 typedef struct _VglTrayIconClass VglTrayIconClass;
+typedef struct _VglTrayIconPrivate VglTrayIconPrivate;
 
 struct _VglTrayIcon
 {
 	GObject parent_instance;
+        VglTrayIconPrivate *priv;
 };
 
 struct _VglTrayIconClass
@@ -35,14 +41,14 @@ struct _VglTrayIconClass
 };
 
 
-GType vgl_tray_icon_get_type(void) G_GNUC_CONST;
+GType
+vgl_tray_icon_get_type                  (void) G_GNUC_CONST;
 
 
 /* Public methods */
 
-VglTrayIcon *vgl_tray_icon_create (void);
-void vgl_tray_icon_notify_playback (VglTrayIcon *vti, LastfmTrack *track);
-void vgl_tray_icon_show_notifications (VglTrayIcon *vti, gboolean show_notifications);
+VglTrayIcon *
+vgl_tray_icon_create                    (VglController *controller);
 
 G_END_DECLS
 
